==> openshift-model-console-6.2.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleYAMLSampleFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsoleYAMLSampleFluent<A extends ConsoleYAMLSampleFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ConsoleYAMLSampleFluent.MetadataNested<A> withNewMetadata();
  public ConsoleYAMLSampleFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ConsoleYAMLSampleFluent.MetadataNested<A> editMetadata();
  public ConsoleYAMLSampleFluent.MetadataNested<A> editOrNewMetadata();
  public ConsoleYAMLSampleFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleYAMLSampleSpec getSpec();
  public ConsoleYAMLSampleSpec buildSpec();
  public A withSpec(ConsoleYAMLSampleSpec spec);
  public Boolean hasSpec();
  public ConsoleYAMLSampleFluent.SpecNested<A> withNewSpec();
  public ConsoleYAMLSampleFluent.SpecNested<A> withNewSpecLike(ConsoleYAMLSampleSpec item);
  public ConsoleYAMLSampleFluent.SpecNested<A> editSpec();
  public ConsoleYAMLSampleFluent.SpecNested<A> editOrNewSpec();
  public ConsoleYAMLSampleFluent.SpecNested<A> editOrNewSpecLike(ConsoleYAMLSampleSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ConsoleYAMLSampleFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ConsoleYAMLSampleSpecFluent<ConsoleYAMLSampleFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleYAMLSampleFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsoleYAMLSampleFluent<A extends ConsoleYAMLSampleFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ConsoleYAMLSampleFluent.MetadataNested<A> withNewMetadata();
  public ConsoleYAMLSampleFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ConsoleYAMLSampleFluent.MetadataNested<A> editMetadata();
  public ConsoleYAMLSampleFluent.MetadataNested<A> editOrNewMetadata();
  public ConsoleYAMLSampleFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleYAMLSampleSpec getSpec();
  public ConsoleYAMLSampleSpec buildSpec();
  public A withSpec(ConsoleYAMLSampleSpec spec);
  public Boolean hasSpec();
  public ConsoleYAMLSampleFluent.SpecNested<A> withNewSpec();
  public ConsoleYAMLSampleFluent.SpecNested<A> withNewSpecLike(ConsoleYAMLSampleSpec item);
  public ConsoleYAMLSampleFluent.SpecNested<A> editSpec();
  public ConsoleYAMLSampleFluent.SpecNested<A> editOrNewSpec();
  public ConsoleYAMLSampleFluent.SpecNested<A> editOrNewSpecLike(ConsoleYAMLSampleSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ConsoleYAMLSampleFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ConsoleYAMLSampleSpecFluent<ConsoleYAMLSampleFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}
